@@ -2,7 +2,7 @@
 # This package is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #
-# $Id: ModInt.pm 57 2015-05-17 22:39:05Z demetri $
+# $Id: ModInt.pm 60 2015-05-18 08:47:12Z demetri $
 
 package Math::ModInt;
 
@@ -42,7 +42,7 @@ BEGIN {
     our @ISA       = qw(Exporter);
     our @EXPORT_OK = qw(mod divmod qmod);
     our @CARP_NOT  = qw(Math::ModInt::ChineseRemainder);
-    our $VERSION   = '0.009';
+    our $VERSION   = '0.011';
 }
 
 sub _max_modulus_perl {
@@ -97,9 +97,11 @@ sub _best_class {
 
 sub _load {
     my ($class) = @_;
-    local $@;
-    ($loaded{$class} ||= eval "require $class")
-        or LoadingFailure->raise($class);
+    do {
+        local $@;
+        $loaded{$class} ||= eval "require $class"
+    }
+    or LoadingFailure->raise($class);
     return $class;
 }
 
@@ -318,7 +320,7 @@ Math::ModInt - modular integer arithmetic
 
 =head1 VERSION
 
-This documentation refers to version 0.009 of Math::ModInt.
+This documentation refers to version 0.011 of Math::ModInt.
 
 =head1 SYNOPSIS
 
